@@ -1,6 +1,7 @@
 use {
     crate::{
         cols::Cols,
+        filter::Filter,
         units::Units,
         sorting::Sorting,
     },
@@ -30,10 +31,18 @@ pub struct Args {
     #[argh(switch)]
     pub list_cols: bool,
 
+    /// fetch stats of remote volumes, 'yes', 'no' or 'auto'
+    #[argh(option, default = "Default::default()")]
+    pub remote_stats: BoolArg,
+
     /// columns, eg `-c +inodes` or `-c id+dev+default`
     #[argh(option, default = "Default::default()", short = 'c')]
     pub cols: Cols,
 
+    /// filter, eg `-f '(size<35G | remote=false) & type=xfs'`
+    #[argh(option, default = "Default::default()", short = 'f')]
+    pub filter: Filter,
+
     /// sort, eg `-s inodes` or `-s size-asc`
     #[argh(option, default = "Default::default()", short = 's')]
     pub sort: Sorting,
