@@ -1,6 +1,8 @@
 mod args;
 mod col;
+mod col_expr;
 mod cols;
+mod filter;
 mod json;
 mod list_cols;
 mod normal;
@@ -30,7 +32,12 @@ fn main() {
         list_cols::print(args.color());
         return;
     }
-    let mut mounts = match lfs_core::read_mounts() {
+    let mut options = lfs_core::ReadOptions::default();
+    options.remote_stats(match args.remote_stats.value() {
+        Some(false) => false,
+        _ => true,
+    });
+    let mut mounts = match lfs_core::read_mounts(&options) {
         Ok(mounts) => mounts,
         Err(e) => {
             eprintln!("Error reading mounts: {}", e);
@@ -51,6 +58,14 @@ fn main() {
         let dev = lfs_core::DeviceId::from(md.dev());
         mounts.retain(|m| m.info.dev == dev);
     }
+    args.sort.sort(&mut mounts);
+    let mounts = match args.filter.filter(&mounts) {
+        Ok(mounts) => mounts,
+        Err(e) => {
+            eprintln!("Error in filter evaluation: {}", e);
+            return;
+        }
+    };
     if args.json {
         println!(
             "{}",
@@ -62,7 +77,6 @@ fn main() {
         println!("no mount to display - try\n    lfs -a");
         return;
     }
-    args.sort.sort(&mut mounts);
     table::print(&mounts, args.color(), &args);
 }
 
